==> kadaster-gds2-1.2-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstselectie/v20130701/AfgifteSelectieCriteriaType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstselectie.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_proces.v20130701.FilterDatumTijdType;
import nl.kadaster.schemas.gds2.afgifte_proces.v20130701.SorteringType;


/**
 * <p>Java class for AfgifteSelectieCriteriaType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="AfgifteSelectieCriteriaType">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstselectie/v20130701}BestandKenmerken" minOccurs="0"/>
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701}Periode" minOccurs="0"/>
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701}NogNietGerapporteerd" minOccurs="0"/>
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701}Sortering" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AfgifteSelectieCriteriaType", propOrder = {
    "bestandKenmerken",
    "periode",
    "nogNietGerapporteerd",
    "sortering"
})
public class AfgifteSelectieCriteriaType {

    @XmlElement(name = "BestandKenmerken")
    protected BestandKenmerkenType bestandKenmerken;
    @XmlElement(name = "Periode", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701")
    protected FilterDatumTijdType periode;
    @XmlElement(name = "NogNietGerapporteerd", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701")
    protected Boolean nogNietGerapporteerd;
    @XmlElement(name = "Sortering", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701")
    protected SorteringType sortering;

    /**
     * Gets the value of the bestandKenmerken property.
     * 
     * @return
     *     possible object is
     *     {@link BestandKenmerkenType }
     *     
     */
    public BestandKenmerkenType getBestandKenmerken() {
        return bestandKenmerken;
    }

    /**
     * Sets the value of the bestandKenmerken property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandKenmerkenType }
     *     
     */
    public void setBestandKenmerken(BestandKenmerkenType value) {
        this.bestandKenmerken = value;
    }

    /**
     * Gets the value of the periode property.
     * 
     * @return
     *     possible object is
     *     {@link FilterDatumTijdType }
     *     
     */
    public FilterDatumTijdType getPeriode() {
        return periode;
    }

    /**
     * Sets the value of the periode property.
     * 
     * @param value
     *     allowed object is
     *     {@link FilterDatumTijdType }
     *     
     */
    public void setPeriode(FilterDatumTijdType value) {
        this.periode = value;
    }

    /**
     * Gets the value of the nogNietGerapporteerd property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isNogNietGerapporteerd() {
        return nogNietGerapporteerd;
    }

    /**
     * Sets the value of the nogNietGerapporteerd property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setNogNietGerapporteerd(Boolean value) {
        this.nogNietGerapporteerd = value;
    }

    /**
     * Gets the value of the sortering property.
     * 
     * @return
     *     possible object is
     *     {@link SorteringType }
     *     
     */
    public SorteringType getSortering() {
        return sortering;
    }

    /**
     * Sets the value of the sortering property.
     * 
     * @param value
     *     allowed object is
     *     {@link SorteringType }
     *     
     */
    public void setSortering(SorteringType value) {
        this.sortering = value;
    }

}

==> kadaster-gds2-2.1-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstselectie/v20130701/AfgifteSelectieCriteriaType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstselectie.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_proces.v20130701.FilterDatumTijdType;
import nl.kadaster.schemas.gds2.afgifte_proces.v20130701.SorteringType;


/**
 * <p>Java class for AfgifteSelectieCriteriaType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="AfgifteSelectieCriteriaType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstselectie/v20130701}BestandKenmerken" minOccurs="0"/&gt;
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701}Periode" minOccurs="0"/&gt;
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701}NogNietGerapporteerd" minOccurs="0"/&gt;
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701}Sortering" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AfgifteSelectieCriteriaType", propOrder = {
    "bestandKenmerken",
    "periode",
    "nogNietGerapporteerd",
    "sortering"
})
public class AfgifteSelectieCriteriaType {

    @XmlElement(name = "BestandKenmerken")
    protected BestandKenmerkenType bestandKenmerken;
    @XmlElement(name = "Periode", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701")
    protected FilterDatumTijdType periode;
    @XmlElement(name = "NogNietGerapporteerd", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701")
    protected Boolean nogNietGerapporteerd;
    @XmlElement(name = "Sortering", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701")
    protected SorteringType sortering;

    /**
     * Gets the value of the bestandKenmerken property.
     * 
     * @return
     *     possible object is
     *     {@link BestandKenmerkenType }
     *     
     */
    public BestandKenmerkenType getBestandKenmerken() {
        return bestandKenmerken;
    }

    /**
     * Sets the value of the bestandKenmerken property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandKenmerkenType }
     *     
     */
    public void setBestandKenmerken(BestandKenmerkenType value) {
        this.bestandKenmerken = value;
    }

    /**
     * Gets the value of the periode property.
     * 
     * @return
     *     possible object is
     *     {@link FilterDatumTijdType }
     *     
     */
    public FilterDatumTijdType getPeriode() {
        return periode;
    }

    /**
     * Sets the value of the periode property.
     * 
     * @param value
     *     allowed object is
     *     {@link FilterDatumTijdType }
     *     
     */
    public void setPeriode(FilterDatumTijdType value) {
        this.periode = value;
    }

    /**
     * Gets the value of the nogNietGerapporteerd property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isNogNietGerapporteerd() {
        return nogNietGerapporteerd;
    }

    /**
     * Sets the value of the nogNietGerapporteerd property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setNogNietGerapporteerd(Boolean value) {
        this.nogNietGerapporteerd = value;
    }

    /**
     * Gets the value of the sortering property.
     * 
     * @return
     *     possible object is
     *     {@link SorteringType }
     *     
     */
    public SorteringType getSortering() {
        return sortering;
    }

    /**
     * Sets the value of the sortering property.
     * 
     * @param value
     *     allowed object is
     *     {@link SorteringType }
     *     
     */
    public void setSortering(SorteringType value) {
        this.sortering = value;
    }

}
